==> flutter_ali_oauth-0.0.2.tar.gz: android/src/main/java/com/stl/flutter_ali_oauth/event/TokenEvent.java <==
package com.stl.flutter_ali_oauth.event;


import android.os.Handler;
import android.os.Looper;
import android.util.Log;

import com.google.gson.Gson;
import com.stl.flutter_ali_oauth.FlutterAliOauthPlugin;
import com.stl.flutter_ali_oauth.bean.TokenResult;

import java.util.concurrent.Future;

import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.EventChannel;

/**
 * @author Ricky
 * @date 2020/10/22
 * Token回调推送
 */
public class TokenEvent implements IMessageEvent<String> {

    private static TokenEvent instance;
    private EventChannel.EventSink eventSink;

    public static TokenEvent getInstance() {
        if (instance == null) {
            instance = new TokenEvent();
        }
        return instance;
    }

    private TokenEvent() {
    }

    private EventChannel eventChannel;

    private String EVENT_CHANNEL = "com.stl/tokenEvent";

    private boolean onCancel=false;

    @Override
    public void initEventChannel(BinaryMessenger messenger) {
        if (messenger==null){
            Log.i("TokenEvent", "messenger==null");
        }
        eventChannel = new EventChannel(messenger, EVENT_CHANNEL);
        eventChannel.setStreamHandler(new EventChannel.StreamHandler() {
            @Override
            public void onListen(Object arguments, EventChannel.EventSink events) {
                Log.i("TokenEvent", "arguments:"+arguments.toString());
                eventSink = events;
                onCancel=false;
            }

            @Override
            public void onCancel(Object o) {
                Log.i("TokenEvent", "Object:"+o.toString());
                onCancel=true;
            }
        });
    }

    @Override
    public void sendSuccess(final String message) {
        if (eventSink != null) {
            eventSink.success(message);
        }else {
            //超过300ms就不发送了,不作递归处理
            new Handler(Looper.getMainLooper()).postDelayed(new Runnable() {
                @Override
                public void run() {
                    if (eventSink != null) {
                        Log.i("sendSuccess", "eventSink.success(message)");
                        eventSink.success(message);
                    }
                }
            },300);
        }
    }

    @Override
    public void sendError(String message) {
        sendSuccess(message);
//        if (eventSink != null) {
//            TokenResult tokenResult = new Gson().fromJson(message, TokenResult.class);
//            eventSink.error(tokenResult.getCode(), tokenResult.getMsg(), message);
//        }
    }


}

==> flutter_ali_oauth-0.0.3.tar.gz: android/src/main/java/com/stl/flutter_ali_oauth/event/TokenEvent.java <==
package com.stl.flutter_ali_oauth.event;


import android.os.Handler;
import android.os.Looper;
import android.util.Log;

import com.google.gson.Gson;
import com.stl.flutter_ali_oauth.FlutterAliOauthPlugin;
import com.stl.flutter_ali_oauth.bean.TokenResult;

import java.util.concurrent.Future;

import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.EventChannel;

/**
 * @author Ricky
 * @date 2020/10/22
 * Token回调推送
 */
public class TokenEvent implements IMessageEvent<String> {

    private static TokenEvent instance;
    private EventChannel.EventSink eventSink;

    public static TokenEvent getInstance() {
        if (instance == null) {
            instance = new TokenEvent();
        }
        return instance;
    }

    private TokenEvent() {
    }

    private EventChannel eventChannel;

    private String EVENT_CHANNEL = "com.stl/tokenEvent";

    private boolean onCancel=false;

    @Override
    public void initEventChannel(BinaryMessenger messenger) {
        Log.i("TokenEvent", "initEventChannel");
        try {
            if (messenger==null){
                Log.i("TokenEvent", "messenger==null");
            }else {
                Log.i("TokenEvent", "messenger!=null");
            }
            eventChannel = new EventChannel(messenger, EVENT_CHANNEL);
            eventChannel.setStreamHandler(new EventChannel.StreamHandler() {
                @Override
                public void onListen(Object arguments, EventChannel.EventSink events) {
                    Log.i("TokenEvent", "onListen:");
                    eventSink = events;
                    onCancel=false;
                }

                @Override
                public void onCancel(Object o) {
                    if (o!=null){
                        Log.i("TokenEvent", "onCancel Object:"+o.toString());
                    }
                    onCancel=true;
                }
            });
        }catch(Exception e){
            Log.i("TokenEvent", "Exception:"+e.getCause());
            Log.i("TokenEvent", "Exception:"+e.getMessage());
        }

    }

    @Override
    public void sendSuccess(final String message) {
        Log.i("TokenEvent", "sendSuccess");
        if (eventSink != null) {
            eventSink.success(message);
        }else {
            Log.i("TokenEvent", "sendSuccess1");
            //超过300ms就不发送了,不作递归处理
            new Handler(Looper.getMainLooper()).postDelayed(new Runnable() {
                @Override
                public void run() {
                    if (eventSink != null) {
                        Log.i("sendSuccess", "eventSink.success(message)");
                        eventSink.success(message);
                    }
                }
            },300);
        }
    }

    @Override
    public void sendError(String message) {
        sendSuccess(message);
//        if (eventSink != null) {
//            TokenResult tokenResult = new Gson().fromJson(message, TokenResult.class);
//            eventSink.error(tokenResult.getCode(), tokenResult.getMsg(), message);
//        }
    }


}
